@@ -10,8 +10,11 @@ class baseapi:
 
 
 class CreateableAPIResource:
+    def _create(self, path, *args, **kwargs) -> Result:
+        return self.client.post(path, json=args[0] if args else kwargs)
+
     def create(self, *args, **kwargs) -> Result:
-        return self.client.post(self.path, json=args[0] if args else kwargs)
+        return self._create(self.path, *args, **kwargs)
 
 
 class DeletableAPIResource:
@@ -27,18 +30,19 @@ class ListableAPIResource:
         next_token = result.pagination["next"]
         yield result
         while next_token:
-            result = self.client.get(
-                self.path, url_override=next_token, params=result.params
-            )
+            result = self.client.get(self.path, url_override=next_token, params=result.params)
             yield result
             next_token = result.pagination["next"]
 
-    def list(self, **kwargs) -> Result:
-        return self.client.get(self.path, params=kwargs)
+    def _list(self, path, **kwargs) -> Result:
+        return self.client.get(path, params=kwargs)
 
-    def all(self, **kwargs):
+    def list(self, **kwargs) -> Result:
+        return self._list(self.path, **kwargs)
+
+    def _all(self, path, **kwargs):
         result = None
-        for page in self.paginate(self.client.get(self.path, params=kwargs)):
+        for page in self.paginate(self._list(path, **kwargs)):
             if not result:
                 result = page
             else:
@@ -48,6 +52,9 @@ class ListableAPIResource:
         result.pagination["previous"] = None
         return result
 
+    def all(self, **kwargs):
+        return self._all(self.path, **kwargs)
+
 
 class RetrievableAPIResource:
     def get(self, id: str | int) -> Result:
@@ -86,3 +93,31 @@ class ROAPIResource(
     UpdateableAPIResource,
 ):
     pass
+
+
+class CreateablePathAPIResource:
+    def create(self, *args, **kwargs) -> Result:
+        path = self.path.format(id=id)
+        return self._create(path, *args, **kwargs)
+
+
+class ListablePathAPIResource:
+    def list(self, **kwargs) -> Result:
+        path = self.path.format(id=id)
+        return self._list(path, **kwargs)
+
+    def all(self, **kwargs):
+        path = self.path.format(id=id)
+        return self._all(path, **kwargs)
+
+
+class AvailableAPIResource(
+    baseapi,
+    CreateablePathAPIResource,
+    ListablePathAPIResource,
+):
+    pass
+
+
+class ElevationAPIResource(baseapi, ListablePathAPIResource):
+    pass
